@@ -5,17 +5,13 @@ use utf8;
 use App::cpm::Distribution;
 use App::cpm::Job;
 use App::cpm::Logger;
-use Module::CoreList;
 use Module::Metadata;
 use version;
-our $VERSION = '0.297';
+our $VERSION = '0.298';
 
 sub new {
     my ($class, %option) = @_;
-    if (!exists $Module::CoreList::version{$]}) {
-        die "Module::CoreList does not have your perl $^V entry, abort.\n";
-    }
-    bless {
+    my $self = bless {
         %option,
         installed_distributions => 0,
         jobs => +{},
@@ -24,6 +20,13 @@ sub new {
         _fail_install => +{},
         _is_installed => +{},
     }, $class;
+    if ($self->{target_perl}) {
+        require Module::CoreList;
+        if (!exists $Module::CoreList::version{$]}) {
+            die "Module::CoreList does not have your perl $^V entry, abort.\n";
+        }
+    }
+    $self;
 }
 
 sub fail {
@@ -107,6 +110,7 @@ sub _calculate_jobs {
 
     if (my @dists = grep { $_->fetched && !$_->registered } @distributions) {
         for my $dist (@dists) {
+            local $self->{logger}->{context} = $dist->distvname;
             my ($is_satisfied, @need_resolve)
                 = $self->is_satisfied($dist->configure_requirements);
             if ($is_satisfied) {
@@ -121,7 +125,6 @@ sub _calculate_jobs {
                 );
             } elsif (@need_resolve and !$dist->deps_registered) {
                 $dist->deps_registered(1);
-                local $self->{logger}->{context} = $dist->distvname;
                 my $msg = sprintf "Found configure dependencies: %s",
                     join(", ", map { sprintf "%s (%s)", $_->{package}, $_->{version_range} || 0 }  @need_resolve);
                 $self->{logger}->log($msg);
@@ -129,7 +132,8 @@ sub _calculate_jobs {
                 $self->{_fail_install}{$dist->distfile}++ unless $ok;
             } elsif (!defined $is_satisfied) {
                 my ($req) = grep { $_->{package} eq "perl" } @{$dist->configure_requirements};
-                my $msg = sprintf "%s requires perl %s", $dist->distvname, $req->{version_range};
+                my $msg = sprintf "%s requires perl %s, but you have only %s", $dist->distvname, $req->{version_range}, $];
+                $self->{logger}->log($msg);
                 App::cpm::Logger->log(result => "FAIL", message => $msg);
                 $self->{_fail_install}{$dist->distfile}++;
             }
@@ -138,6 +142,7 @@ sub _calculate_jobs {
 
     if (my @dists = grep { $_->configured && !$_->registered } @distributions) {
         for my $dist (@dists) {
+            local $self->{logger}->{context} = $dist->distvname;
             my ($is_satisfied, @need_resolve)
                 = $self->is_satisfied($dist->requirements);
             if ($is_satisfied) {
@@ -153,15 +158,15 @@ sub _calculate_jobs {
                 );
             } elsif (@need_resolve and !$dist->deps_registered) {
                 $dist->deps_registered(1);
-                local $self->{logger}->{context} = $dist->distvname;
                 my $msg = sprintf "Found dependencies: %s",
                     join(", ", map { sprintf "%s (%s)", $_->{package}, $_->{version_range} || 0 }  @need_resolve);
                 $self->{logger}->log($msg);
                 my $ok = $self->_register_resolve_job(@need_resolve);
                 $self->{_fail_install}{$dist->distfile}++ unless $ok;
             } elsif (!defined $is_satisfied) {
-                my ($req) = grep { $_->{package} eq "perl" } @{$dist->configure_requirements};
-                my $msg = sprintf "%s requires perl %s", $dist->distvname, $req->{version_range};
+                my ($req) = grep { $_->{package} eq "perl" } @{$dist->requirements};
+                my $msg = sprintf "%s requires perl %s, but you have only %s", $dist->distvname, $req->{version_range}, $];
+                $self->{logger}->log($msg);
                 App::cpm::Logger->log(result => "FAIL", message => $msg);
                 $self->{_fail_install}{$dist->distfile}++;
             }
